/* ignuit - Educational software for the GNOME, following the Leitner
 * flash-card system.
 *
 * Copyright (C) 2008 Timothy Musson
 *
 * <trmusson@ihug.co.nz>
 * http://homepages.ihug.co.nz/~trmusson/programs.html#ignuit
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */


#include <config.h>
#include <gnome.h>
#include <gconf/gconf-client.h>

#include "main.h"
#include "file.h"
#include "fileio.h"
#include "app-window.h"



gboolean
date_today (GDate *date)
{
    /* Fill an existing GDate with today's date. */

    time_t ttime;

    if (time (&ttime) == -1) {
        return FALSE;
    }
    g_date_set_time_t (date, ttime);
    return TRUE;
}


void
ignuit_free (Ignuit *ig)
{

    file_free (ig->file, TRUE);
    prefs_free (ig->prefs);

    g_rand_free (ig->grand);
    g_date_free (ig->today);

    if (ig->recent_search_terms) {
        g_list_foreach (ig->recent_search_terms, (GFunc)g_free, NULL);
        g_list_free (ig->recent_search_terms);
    }

    g_free (ig);
}


int
main (int argc, char *argv[])
{
    GError *err = NULL;
    Ignuit *ig;


#ifdef ENABLE_NLS
    bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
    bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
    textdomain (GETTEXT_PACKAGE);
#endif

    ig = g_new0 (Ignuit, 1);

    ig->program = gnome_program_init (PACKAGE, VERSION,
        LIBGNOMEUI_MODULE, argc, argv,
        GNOME_PROGRAM_STANDARD_PROPERTIES, NULL);

    gconf_init (argc, argv, NULL);

    ig->today = g_date_new ();
    ig->grand = g_rand_new ();
    ig->prefs = prefs_load ();

    if (argc > 2) {
        g_printerr ("Usage: %s [OPTIONS] [FILENAME]\n", argv[0]);
        exit (EXIT_FAILURE);
    }

    if (argc > 1) {
        ig->file = fileio_load (argv[1], &err);
        if (ig->file == NULL) {
            g_warning ("%s\n", err->message);
            g_error_free (err);
        }
    }

    if (ig->file == NULL) {
        ig->file = file_new ();
        file_add_category (ig->file, category_new (NULL));
    }

    if (file_get_categories (ig->file)) {
        Category *first;
        first = CATEGORY(file_get_categories (ig->file));
        file_set_current_category (ig->file, first);
    }

    app_window (ig);

    gtk_main ();

    ignuit_free (ig);

    return EXIT_SUCCESS;
}

